[−][src]Enum ms_oforms::common::VarType
Variants
EmptyNullI2I4R4R8CyDateBStrDispatchErrorBoolVariantUnknownDecimalI1UI1UI2UI4I8UI8IntUIntVoidHResultPtrSafearrayCArrayUserDefinedLPStrLPWStrRecordIntPtrUIntPtrArrayByRefTrait Implementations
impl PartialEq<VarType> for VarType[src]
fn eq(&self, other: &VarType) -> bool[src]
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
This method tests for !=.
impl Eq for VarType[src]
impl Debug for VarType[src]
impl ToPrimitive for VarType[src]
fn to_i64(&self) -> Option<i64>[src]
fn to_u64(&self) -> Option<u64>[src]
fn to_isize(&self) -> Option<isize>[src]
Converts the value of self to an isize.
fn to_i8(&self) -> Option<i8>[src]
Converts the value of self to an i8.
fn to_i16(&self) -> Option<i16>[src]
Converts the value of self to an i16.
fn to_i32(&self) -> Option<i32>[src]
Converts the value of self to an i32.
fn to_i128(&self) -> Option<i128>[src]
Converts the value of self to an i128. Read more
fn to_usize(&self) -> Option<usize>[src]
Converts the value of self to a usize.
fn to_u8(&self) -> Option<u8>[src]
Converts the value of self to an u8.
fn to_u16(&self) -> Option<u16>[src]
Converts the value of self to an u16.
fn to_u32(&self) -> Option<u32>[src]
Converts the value of self to an u32.
fn to_u128(&self) -> Option<u128>[src]
Converts the value of self to an u128. Read more
fn to_f32(&self) -> Option<f32>[src]
Converts the value of self to an f32.
fn to_f64(&self) -> Option<f64>[src]
Converts the value of self to an f64.
impl FromPrimitive for VarType[src]
fn from_i64(n: i64) -> Option<Self>[src]
fn from_u64(n: u64) -> Option<Self>[src]
fn from_isize(n: isize) -> Option<Self>[src]
Convert an isize to return an optional value of this type. If the value cannot be represented by this value, then None is returned. Read more
fn from_i8(n: i8) -> Option<Self>[src]
Convert an i8 to return an optional value of this type. If the type cannot be represented by this value, then None is returned. Read more
fn from_i16(n: i16) -> Option<Self>[src]
Convert an i16 to return an optional value of this type. If the type cannot be represented by this value, then None is returned. Read more
fn from_i32(n: i32) -> Option<Self>[src]
Convert an i32 to return an optional value of this type. If the type cannot be represented by this value, then None is returned. Read more
fn from_i128(n: i128) -> Option<Self>[src]
Convert an i128 to return an optional value of this type. If the type cannot be represented by this value, then None is returned. Read more
fn from_usize(n: usize) -> Option<Self>[src]
Convert a usize to return an optional value of this type. If the type cannot be represented by this value, then None is returned. Read more
fn from_u8(n: u8) -> Option<Self>[src]
Convert an u8 to return an optional value of this type. If the type cannot be represented by this value, then None is returned. Read more
fn from_u16(n: u16) -> Option<Self>[src]
Convert an u16 to return an optional value of this type. If the type cannot be represented by this value, then None is returned. Read more
fn from_u32(n: u32) -> Option<Self>[src]
Convert an u32 to return an optional value of this type. If the type cannot be represented by this value, then None is returned. Read more
fn from_u128(n: u128) -> Option<Self>[src]
Convert an u128 to return an optional value of this type. If the type cannot be represented by this value, then None is returned. Read more
fn from_f32(n: f32) -> Option<Self>[src]
Convert a f32 to return an optional value of this type. If the type cannot be represented by this value, then None is returned. Read more
fn from_f64(n: f64) -> Option<Self>[src]
Convert a f64 to return an optional value of this type. If the type cannot be represented by this value, then None is returned. Read more