[−][src]Enum ms_oforms::controls::form::designex::DblClickControlMode
Variants
InheritUse the same value as the client application design-time settings.
SelectTextSelect any text that is under the cursor.
EditCodeDisplay and set focus to the code associated with the control that is under the cursor.
EditPropertiesDisplay the properties of the control that is under the cursor.