[−][src]Enum ms_oforms::controls::form::Cycle
Specifies the behavior of the TAB key in the last control of a form
Variants
AllFormsThe focus is next set to the first control on the next form, returning to the first control of this form only after all controls on all other forms have been reached.
CurrentFormThe focus is next set to the first control on this form, ignoring other forms.