[−]Struct ms_oforms::controls::form::FormFlags
A bit field that specifies Boolean properties of a form.
Methods
impl FormFlags
pub const ENABLED: FormFlags
Specifies whether the form is enabled.
pub const DESINKPERSISTED: FormFlags
Specifies whether Design Extender properties are persisted with this form.
pub const DONTSAVECLASSTABLE: FormFlags
Specifies whether the Class Table of a form is not persisted. A value of zero specifies that the Class Table is persisted if it is not empty.
pub const fn empty() -> FormFlags
Returns an empty set of flags
pub const fn all() -> FormFlags
Returns the set containing all flags.
pub const fn bits(&self) -> u32
Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<FormFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub const fn from_bits_truncate(bits: u32) -> FormFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
pub const fn is_empty(&self) -> bool
Returns true if no flags are currently stored.
pub const fn is_all(&self) -> bool
Returns true if all flags are currently set.
pub const fn intersects(&self, other: FormFlags) -> bool
Returns true if there are flags common to both self and other.
pub const fn contains(&self, other: FormFlags) -> bool
Returns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: FormFlags)
Inserts the specified flags in-place.
pub fn remove(&mut self, other: FormFlags)
Removes the specified flags in-place.
pub fn toggle(&mut self, other: FormFlags)
Toggles the specified flags in-place.
pub fn set(&mut self, other: FormFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.